from django.contrib.auth.signals import user_logged_in
from django.dispatch import receiver
from django.conf import settings


superusers = []
if hasattr(settings, 'AUTHSIGNALS_SUPERUSERS'):
    superusers = settings.AUTHSIGNALS_SUPERUSERS


@receiver(user_logged_in)
def superuser_mapper(sender, request, user, **kwargs):
    if user and not user.is_superuser and \
       user.username in superusers:
        user.is_superuser = True
        user.save()



from setuptools import setup

setup(
    name='django-authsignals',
    version='0.1.0',
    description='Consolidate common auth signal behavior',
    author='Nik Nyby',
    author_email='ctl-dev@columbia.edu',
    url='https://github.com/ccnmtl/django-authsignals',
    install_requires=['Django'],
    packages=['authsignals'],
)
